# VizQ

## Description
Brief description of the project. **Must include project's objective and scope**

## Installation
Instructions on how to install the project

## Usage
Instructions on how to use the project

## Contributing
Instructions on how to contribute to the project

## References
Link to references used in the project (Books, posts, videos, courses, repos, etc.)
